{ config, pkgs, lib, home, ... }:

{ 
  home.packages = with pkgs; [ 
    nixfmt
    jetbrains.idea-ultimate
    jetbrains.jdk
    vscode
  ]; 

  programs.neovim = {
    enable = true; 
    extraConfig = ''
      # syntax
      syntax enable

      # color themes
      set termguicolors
      colorscheme molokai

      # wildcard mode
      set wildmode=longest:full,full
      
      # remapping popup menu (command autocompletion)
      set cnoremap <expr> <up> pumvisible() ? "<C-p>" : "<up>
      set cnoremap <expr> <down> pumvisible() ? "<C-n>" : "<down>"
      set cnoremap <expr> <CR> pumvisible()? "<C-e>":"<CR>"                                                                                                                                                                                                                                                                                            
      # set line numbers
      set number

      # YouCompleteMe
      let g:ycm_key_list_stop_completion = ['<C-y>', '<CR>'] 
      let g:ycm_key_list_select_completion = ['<Up>', '<Down>', '<TAB>'] 
    '';

    viAlias = true; 
    vimAlias = true;
    plugins = with pkgs.vimPlugins; [ 
      vim-nix 
      molokai
      YouCompleteMe
      vim-airline 
      vim-airline-themes
      vim-lsp 
      vim-indent-guides
      vim-signify 
    ];
  };

}
